import os

class cd:
    """
        Context manager for changing the current working directory 
        
        class cd()

        Example: 
            with cd(directory):
                print (os.getcwd()) 

            print (os.getcwd()) ## Moves you back to the originating directory on exit
    """
    def __init__(self, newPath):
        self.newPath = newPath   

    def __enter__(self):
        self.savedPath = os.getcwd()
        os.chdir(self.newPath)

    def __exit__(self, etype, value, traceback):
        os.chdir(self.savedPath)


import datetime

def build_date_array(days=1, start_date=str(datetime.date.today()), date_format='%Y-%m-%d', mon=True, tues=True, wed=True, thur=True, fri=True, sat=True, sun=True, weekend=True):
    dates = []
    
    start_date = datetime.datetime.strptime(start_date, date_format)
    
    start_year = int(start_date.strftime('%Y'))
    start_month = int(start_date.strftime('%m'))
    start_day = int(start_date.strftime('%d'))
    date = datetime.date(start_year, start_month, start_day)
    
    counter = 0
    
    if not weekend:
        sat = False
        sun = False
    
    while len(dates) < days:
        start_year = int(date.strftime('%Y'))
        start_month = int(date.strftime('%m'))
        start_day = int(date.strftime('%d'))
        #date = datetime.date(start_year, start_month, start_day) + datetime.timedelta(days=counter)
    
        ### Return the day of the week as an integer, where Monday is 0 and Sunday is 6
        day_of_the_week = datetime.date(start_year, start_month, start_day).weekday()

        if mon == True and day_of_the_week == 0:
            dates.append(date.strftime('%Y-%m-%d'))
        if tues == True and day_of_the_week == 1:
            dates.append(date.strftime('%Y-%m-%d'))
        if wed == True and day_of_the_week == 2:
            dates.append(date.strftime('%Y-%m-%d'))
        if thur == True and day_of_the_week == 3:
            dates.append(date.strftime('%Y-%m-%d'))
        if fri == True and day_of_the_week == 4:
            dates.append(date.strftime('%Y-%m-%d'))
        if sat == True and day_of_the_week == 5:
            dates.append(date.strftime('%Y-%m-%d'))
        if sun == True and day_of_the_week == 6:
            dates.append(date.strftime('%Y-%m-%d'))
            
        counter += 1
        
        date = datetime.date(start_year, start_month, start_day) + datetime.timedelta(days=1)
    
    return dates


import pandas as pd
import numpy as np

def mean_deviation(data, mean=None):
    '''
    DESCRIPTION:
        This function takes a Pandas DataFrame column in and then returns a series of calculated mean deviations
        
    FUNCTION:
        mean_deviation(data)
        
    EXAMPLE:
        data["MeanDeviation"] = pd.Series(mean_deviation(data['column']), index=data.index)
    '''
    diff_values = list()
    if not mean:
        mean = data.mean()
        
    for i in range(0, len(data)):
        diff_value = abs(data[i] - mean)
        diff_values.append(diff_value)
        
    return diff_values

def standard_deviation(data, mean=None):
    '''
    DESCRIPTION:
        This function takes a Pandas DataFrame column in and then returns the calculated standard deviation
        
    FUNCTION:
        standard_deviation(data)
        
    EXAMPLE:
        standard_dev = standard_deviation(data['column'])
    '''
    diff_values = list()
    if not mean:
        mean = data.mean()
        
    for i in range(0, len(data)):
        diff_value = data[i] - mean
        diff_value = diff_value * diff_value
        diff_values.append(diff_value)
        
    standard_dev = np.array(diff_values).mean()
        
    return np.sqrt(standard_dev)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(name='jblib',
                version='1.6.35',
                description='JustBard\'s Python Utilities',
                long_description=long_description,
                long_description_content_type="text/markdown",
                author='Justin Bard',
                author_email='JustinBard@gmail.com',
                url='http://justbard.com',
                packages=setuptools.find_packages(),
                classifiers=[
                    "Programming Language :: Python :: 3",
                    "License :: OSI Approved :: MIT License",
                    "Operating System :: POSIX :: Linux",
                ],
                )
